Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(102)

Unified Diff: src/compiler/common-operator.h

Issue 2729163002: [turbofan] compute arguments length in deoptimizer (Closed)
Patch Set: fix comment Created 3 years, 10 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « src/compiler/code-generator.cc ('k') | src/compiler/common-operator.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: src/compiler/common-operator.h
diff --git a/src/compiler/common-operator.h b/src/compiler/common-operator.h
index b823e0fa154df51dd0346d71d18a98e882c7ab87..d54bcc531109bba685b47ceaef3772c94c7647ce 100644
--- a/src/compiler/common-operator.h
+++ b/src/compiler/common-operator.h
@@ -297,9 +297,9 @@ SparseInputMask SparseInputMaskOf(Operator const*);
ZoneVector<MachineType> const* MachineTypesOf(Operator const*)
WARN_UNUSED_RESULT;
// The ArgumentsElementsState can either describe an unmapped arguments backing
// store or the backing store of the rest parameters. IsRestOf(op) is true in
// the second case.
bool IsRestOf(Operator const*);
// Interface for building common operators that can be used at any level of IR,
@@ -368,6 +368,7 @@ class V8_EXPORT_PRIVATE CommonOperatorBuilder final
const Operator* TypedStateValues(const ZoneVector<MachineType>* types,
SparseInputMask bitmask);
const Operator* ArgumentsElementsState(bool is_rest);
+ const Operator* ArgumentsLengthState(bool is_rest);
const Operator* ObjectState(int pointer_slots);
const Operator* TypedObjectState(const ZoneVector<MachineType>* types);
const Operator* FrameState(BailoutId bailout_id,
@@ -297,9 +297,9 @@ SparseInputMask SparseInputMaskOf(Operator const*);
ZoneVector<MachineType> const* MachineTypesOf(Operator const*)
WARN_UNUSED_RESULT;
-// The ArgumentsElementsState can either describe an unmapped arguments backing
-// store or the backing store of the rest parameters. IsRestOf(op) is true in
-// the second case.
+// The ArgumentsElementsState and ArgumentsLengthState can either describe an
+// unmapped arguments backing store or the backing store of the rest parameters.
+// IsRestOf(op) is true in the second case.
bool IsRestOf(Operator const*);
// Interface for building common operators that can be used at any level of IR,
« no previous file with comments | « src/compiler/code-generator.cc ('k') | src/compiler/common-operator.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698